//------------------------------------------------------------------------------------
//npm install --save dotenv
require('dotenv').config()

//------------------------------------------------------------------------------------
//Get Authorization Token
/*
Your first request in any workflow should be to /auth/get-token in order to receive 
an authorization token. A valid token from this endpoint should be included in the 
headers of all /payment-link requests as 'x-connectfi-token'.

BEFORE CALLING THE getAuthToken FUNCTION: 

* Set CONNECTFI_CLIENTID, CONNECTFI_PASSWORD, and CONNECTFI_BASE_URL in a .env file
(Speak to a support representative to be issued client credentials and URL after 
receiving access to the sandbox.)

*/
const CONNECTFI_CLIENTID = process.env.CONNECTFI_CLIENTID;
const CONNECTFI_PASSWORD = process.env.CONNECTFI_PASSWORD;
const CONNECTFI_BASE_URL = process.env.CONNECTFI_BASE_URL;

async function getAuthToken(login = CONNECTFI_CLIENTID, password = CONNECTFI_PASSWORD) {

    const body = JSON.stringify({
        "user": {
            "login": `${login}`,
            "password": `${password}`
        }
    });
    const config = {
        method: 'POST',
        url: `${CONNECTFI_BASE_URL}/auth/get-token`,
        headers: {
            'Content-Type': "application/json"
        },
        body
    };

    let response;
    try {
        response = await fetch(config.url, config);
        const data = await response.json();
        if (!response.ok) {
            throw new Error(JSON.stringify(data));
        }
        return data.data;
    } catch (err) {
        console.log(err);
    }
}

module.exports = { getAuthToken };