//------------------------------------------------------------------------------------
//npm install --save dotenv
require('dotenv').config()

//------------------------------------------------------------------------------------
//Get Merchant Token
/*
In order to display the Payment Link iframe or to make any /public/merchant requests, you
will need to retrieve a merchant access token (JWT). The merchant token will be included
as a header called 'x-connectfi-jwtoken'.
*/
const CONNECTFI_BASE_URL = process.env.CONNECTFI_BASE_URL;

async function getMerchantToken(authToken, cFiMerchantId) {

    const body = JSON.stringify({
        cFiMerchantId
    });
    const config = {
        method: 'POST',
        url: `${CONNECTFI_BASE_URL}/payment-link/merchant/get-token`,
        headers: {
            'Content-Type': "application/json",
            'x-connectfi-token': authToken //previously obtained authorization token is required
        },
        body
    };

    let response;
    try {
        response = await fetch(config.url, config);
        const data = await response.json();
        if (!response.ok) {
            throw new Error(JSON.stringify(data));
        }
        return data.data;
    } catch (err) {
        console.log(err);
    }
}

module.exports = { getMerchantToken };