const http = require('http');
const fs = require('fs');
const path = require('path');

const { getAuthToken } = require('./pl_auth.js');
const { formData2JSON } = require('./pl_form_data2json.js');
const { paymentLinkMerchantSetUpWalkthrough } = require('./pl_merchant_setup_walkthrough.js');
const { getMerchantToken } = require('./pl_merchant_get_token.js');

const htmlMerchantSetup = fs.readFileSync(path.resolve(__dirname, './html/pl_merchant_setup.html'));
const htmlMerchantToken = fs.readFileSync(path.resolve(__dirname, './html/pl_merchant_token.html'));

const server = http.createServer(async (req, res) => {
    try {
        if (!htmlMerchantSetup || !htmlMerchantToken) {
            throw "Missing HTML";
        }
        if (req.url === '/merchantSetupExample' && req.method !== 'POST') {
            res.write(htmlMerchantSetup);
            res.end();
        }
        if (req.url === '/merchantSetupExample' && req.method === 'POST') {
            let body = '';

            const boundary = req.rawHeaders[req.rawHeaders.findIndex(el => el === 'Content-Type') + 1].replace("multipart/form-data; boundary=", "");
            req.on('data', chunk => {
                body += chunk.toString();
            });
            req.on('end', async () => {
                const result = body.includes(boundary) ? await formData2JSON(body, boundary) : JSON.stringify(body);
                let UNIQUE_MERCHANT_REFERENCE = result.UNIQUE_MERCHANT_REFERENCE ? `${result.UNIQUE_MERCHANT_REFERENCE}` : undefined;
                let merchant = undefined;

                if (UNIQUE_MERCHANT_REFERENCE) {
                    merchant = await paymentLinkMerchantSetUpWalkthrough(undefined, undefined, UNIQUE_MERCHANT_REFERENCE);
                }
                console.log("merchant");
                console.log(merchant);

                res.write(htmlMerchantSetup);
                res.end(JSON.stringify(merchant));
            });
        }
        if (req.url === '/getMerchantToken' && req.method !== 'POST') {
            res.write(htmlMerchantToken);
            res.end();
        }
        if (req.url === '/getMerchantToken' && req.method === 'POST') {
            let body = '';
            const boundary = req.rawHeaders[req.rawHeaders.findIndex(el => el === 'Content-Type') + 1].replace("multipart/form-data; boundary=", "");
            req.on('data', chunk => {
                body += chunk.toString();
            });
            req.on('end', async () => {
                let authToken = undefined;
                let merchantId = undefined;
                let merchantToken = undefined;

                const result = body.includes(boundary) ? await formData2JSON(body, boundary) : JSON.stringify({ body });
                merchantId = result.cFiMerchantId ? `${result.cFiMerchantId}` : undefined;

                if (merchantId) {
                    authToken = await getAuthToken();
                    console.log("authToken");
                    console.log(authToken);
                    merchantToken = await getMerchantToken(authToken.token, merchantId);
                    console.log("merchantToken");
                    console.log(merchantToken);
                }

                res.write(htmlMerchantToken);
                res.end(JSON.stringify(merchantToken));
            });
        }
    } catch (err) {
        console.log(err);
        res.statusCode = 404;
        res.end();
    }
});

server.listen(8000, () => {
    console.log('Server listening on port 8000. Go to http://localhost:8000/merchantSetupExample');
});

module.exports = { server };
